@@ -83,7 +83,7 @@ def break_out_individuals_cpl(
 
   # extract postcode from address if it isn't separate
   if 'postcode' not in combined_df.columns:
-    combined_df[['address_1', 'postcode']] = combined_df.apply(extract_postcode_from_address_series, axis=1).apply(pandas.Series)
+    combined_df[['address_1', 'postcode']] = combined_df.apply(extract_postcode_from_address_series, axis=1)
 
   # ensure the required columns
   required_subset = ['forename', 'surname', 'address_1', 'postcode']
